@@ -5,7 +5,7 @@ use 5.016;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use base qw(Exporter);
 
@@ -226,8 +226,7 @@ sub _process_dirs {
         while ( my $file = readdir $dir ) {
             next if $file eq '.' or $file eq '..';
 
-            # File::Spec->catfile() is too helpful here, goin' old school
-            my $target = "$source/$file";
+            my $target = File::Spec->catfile($source, $file);
 
             _process_dirs($tt2, $tmpl_vars, $template_dir, $target);
         }
@@ -305,7 +304,7 @@ App::Module::Template - Perl module scaffolding with Template Toolkit
 
 =head1 VERSION
 
-This documentation refers to App::Module::Template version 0.01.
+This documentation refers to App::Module::Template version 0.10.
 
 =head1 SYNOPSIS
 
@@ -371,15 +370,15 @@ None reported.
 
 No bugs have been reported.
 
-Please report any issues or feature requests to Trevor S. Cornpropst C<tscornpropst@gmail.com>. Patches are welcome.
+Please report any issues or feature requests to L<https://github.com/tscornpropst/App-Module-Template/issues>. Patches are welcome.
 
 =head1 AUTHOR
 
-Trevor S. Cornpropst
+Trevor S. Cornpropst <tscornpropst@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 Trevor S. Cornpropst C<< tscornpropst@gmail.com >>. All rights reserved.
+Copyright (c) 2014 Trevor S. Cornpropst <tscornpropst@gmail.com>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
